pub enum FillRegionKind {
HorizontalBand {
y_min: f64,
y_max: f64,
},
VerticalBand {
x_min: f64,
x_max: f64,
},
BelowSeries {
series_index: usize,
y_baseline: f64,
},
BetweenSeries {
series_index_1: usize,
series_index_2: usize,
},
Rectangle {
x_min: f64,
y_min: f64,
x_max: f64,
y_max: f64,
},
Polygon {
points: Vec<DataPoint>,
},
}Expand description
Types of fill regions.
Variants
HorizontalBand
Fill between two Y values across the entire X range
VerticalBand
Fill between two X values across the entire Y range
BelowSeries
Fill between a series and a constant Y value
BetweenSeries
Fill between two series
Rectangle
Fill a rectangular region
Polygon
Fill a custom polygon