pub struct ChartDirtyFlags(/* private fields */);Expand description
Dirty flags for tracking what needs to be updated in a chart.
Implementations
Sourceimpl ChartDirtyFlags
impl ChartDirtyFlags
Sourcepub const DATA_CHANGED: Self
pub const DATA_CHANGED: Self
Data has changed completely (requires full rebuild).
Sourcepub const DATA_APPENDED: Self
pub const DATA_APPENDED: Self
Data was appended (can use partial update).
Sourcepub const VIEW_CHANGED: Self
pub const VIEW_CHANGED: Self
View changed (pan/zoom) - need to recalculate pixel coordinates.
Sourcepub const STYLE_CHANGED: Self
pub const STYLE_CHANGED: Self
Style changed (colors, line width, etc.).
Sourcepub const AXES_CHANGED: Self
pub const AXES_CHANGED: Self
Axes changed (range, ticks, labels).
Sourcepub const BOUNDS_CHANGED: Self
pub const BOUNDS_CHANGED: Self
Bounds changed (widget resized).
Sourceimpl ChartDirtyFlags
impl ChartDirtyFlags
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<Self>
pub const fn from_bits(bits: u16) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> Self
pub const fn from_bits_truncate(bits: u16) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> Self
pub const fn from_bits_retain(bits: u16) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl ChartDirtyFlags
impl ChartDirtyFlags
Sourcepub const fn iter(&self) -> Iter<ChartDirtyFlags>
pub const fn iter(&self) -> Iter<ChartDirtyFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ChartDirtyFlags>
pub const fn iter_names(&self) -> IterNames<ChartDirtyFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl ChartDirtyFlags
impl ChartDirtyFlags
Sourcepub fn needs_cache_rebuild(&self) -> bool
pub fn needs_cache_rebuild(&self) -> bool
Check if the cache needs to be rebuilt.
Sourcepub fn is_append_only(&self) -> bool
pub fn is_append_only(&self) -> bool
Check if only data was appended (can use partial update).
Sourcepub fn is_style_only(&self) -> bool
pub fn is_style_only(&self) -> bool
Check if only style changed (no geometry update needed).