pub struct SeriesPixelCache {
pub positions: Vec<Vec2>,
pub x_axis: AxisId,
pub y_axis: AxisId,
pub x_range: (f64, f64),
pub y_range: (f64, f64),
pub data_count: usize,
}Expand description
Cached pixel coordinates for a single data series.
Fields
positions: Vec<Vec2>Pixel positions for each data point.
x_axis: AxisIdX axis ID used for this cache.
y_axis: AxisIdY axis ID used for this cache.
x_range: (f64, f64)Data range that was used to compute these positions.
y_range: (f64, f64)Y data range that was used to compute these positions.
data_count: usizeNumber of data points when cache was built.
Implementations