pub struct SpatialIndex { /* private fields */ }Expand description
Spatial index for O(1) hit testing.
Uses a uniform grid to partition the chart area, allowing fast lookup of points near a given position.
Implementations
Sourceimpl SpatialIndex
impl SpatialIndex
Sourcepub fn new(bounds: Rect, cols: usize, rows: usize) -> Self
pub fn new(bounds: Rect, cols: usize, rows: usize) -> Self
Create a new spatial index for the given bounds.
Sourcepub fn insert(&mut self, pos: Vec2, series_idx: usize, point_idx: usize)
pub fn insert(&mut self, pos: Vec2, series_idx: usize, point_idx: usize)
Insert a point into the index.