TimeSeriesPoint

Struct TimeSeriesPoint 

pub struct TimeSeriesPoint {
    pub time: f64,
    pub value: f64,
    pub min: Option<f64>,
    pub max: Option<f64>,
    pub count: Option<u32>,
}
Time series point with optional OHLC (Open-High-Low-Close) data.

Used for downsampled or aggregated time series data where multiple samples are combined into a single point.

Fields

time: f64

Timestamp (typically in seconds or milliseconds)

value: f64

Primary value (close price, average, etc.)

min: Option<f64>

Optional minimum value in the aggregation period

max: Option<f64>

Optional maximum value in the aggregation period

count: Option<u32>

Optional count of samples aggregated into this point

Implementations

Source

impl TimeSeriesPoint

pub fn new(time: f64, value: f64) -> Self

Create a simple time series point.

pub fn with_range(time: f64, value: f64, min: f64, max: f64) -> Self

Create a point with min/max range.

pub fn aggregated(time: f64, value: f64, min: f64, max: f64, count: u32) -> Self

Create a fully aggregated point.

pub fn to_data_point(&self) -> DataPoint

Convert to a simple DataPoint (ignores OHLC data).