pub enum FillRule {
NonZero,
EvenOdd,
}Expand description
Fill rule for determining interior of a path.
Variants
NonZero
Non-zero winding rule (default).
A point is inside if the winding number is non-zero.
EvenOdd
Even-odd (parity) rule.
A point is inside if the number of crossings is odd.