pub enum SeriesData {
Vec(Vec<DataPoint>),
Ring(RingBuffer<DataPoint>),
TimeSeries(RingBuffer<TimeSeriesPoint>),
Downsampled {
source: Box<SeriesData>,
factor: usize,
cache: Vec<DataPoint>,
source_version: u64,
},
}Expand description
Data storage backend for chart series.
Provides multiple storage options optimized for different use cases:
Vec- Standard vector for static or infrequently updated dataRing- Ring buffer for high-frequency streaming dataTimeSeries- Ring buffer with OHLC support for time seriesDownsampled- Downsampled view of another data source
Variants
Vec(Vec<DataPoint>)
Standard vector storage.
Ring(RingBuffer<DataPoint>)
Ring buffer for streaming data.
TimeSeries(RingBuffer<TimeSeriesPoint>)
Time series with OHLC support.
Downsampled
Downsampled view of source data.
Implementations
Sourceimpl SeriesData
impl SeriesData
Sourcepub fn time_series(capacity: usize) -> Self
pub fn time_series(capacity: usize) -> Self
Create a time series ring buffer with the specified capacity.
Sourcepub fn push(&mut self, point: DataPoint)
pub fn push(&mut self, point: DataPoint)
Push a data point (only works for Vec and Ring variants).
Sourcepub fn push_time_point(&mut self, point: TimeSeriesPoint)
pub fn push_time_point(&mut self, point: TimeSeriesPoint)
Push a time series point (only for TimeSeries variant).
Sourcepub fn iter(&self) -> SeriesDataIter<'_> ⓘ
pub fn iter(&self) -> SeriesDataIter<'_> ⓘ
Iterate over data points.
Sourcepub fn bounds(&self) -> Option<(DataPoint, DataPoint)>
pub fn bounds(&self) -> Option<(DataPoint, DataPoint)>
Get the bounds (min_x, min_y, max_x, max_y) of the data.
Sourcepub fn has_wrapped(&self) -> bool
pub fn has_wrapped(&self) -> bool
Check if the ring buffer has wrapped (data was overwritten).